@@ -40,6 +40,7 @@ Aptitude::Sections
     interpreters	"Interprety pro interpretované jazyky\n Balíky v sekci „interpreters“ obsahují interprety pro jazyky jako Lua, Pike, Smalltalk nebo Tcl a také jejich rozšiřující knihovny. Některé interpretované jazyky se spoustou knihoven mají své vlastní sekce, např. Perl, Python nebo Ruby.";
     introspection	"Podpora introspekce pro programovací jazyky\n Balíky v sekci „introspection“ poskytují podporu introspekce (původně pro GObject). Introspekce znamená schopnost některých programovacích jazyků zkoumat typy a vlastnosti objektů za běhu.";
     java	"Programovací jazyk Java a rozšiřující knihovny\n Balíky ze sekce „java“ poskytují programovací jazyk Java a mnoho rozšiřujících knihoven z dalších zdrojů. Pokud nejste java programátor, nemusíte zde nic vybírat; pokud budou nějaké balíky potřeba, balíkovací systém si díky závislostem nainstaluje vše potřebné.";
+    javascript	"Programovací jazyk JavaScript, knihovny a vývojářské nástroje\n Balíky v sekci „javascript“ poskytují implementace programovacího jazyka JavaScript, vývojářské nástroje pro JavaScript a mnoho rozšiřujících knihoven z dalších zdrojů. Patří sem jak knihovny napsané pro běh ve webových prohlížečích, tak knihovny pro samostatné implementace JavaScriptu, jako je například node.js.";
     kde		"Desktopové prostředí KDE\n KDE je kolekce programů, které společně nabízejí jednoduché a příjemné desktopové prostředí. Balíky v sekci „kde“ jsou přímo součástí prostředí KDE, nebo s ním úzce souvisí.";
     kernel	"Jádro a moduly jádra\n Balíky ze sekce „kernel“ poskytují samotné jádro operačního systému a rozšiřující moduly, které přidávají například podporu pro neobvyklý hardware nebo pro běh virtuálních strojů.";
     libdevel	"Vývojové soubory pro knihovny\n Balíky ze sekce „libdevel“ obsahují soubory vyžadované pro sestavení programů, které využívají knihovny ze sekce „libs“. Běžný uživatel tyto balíky nepotřebuje. (Pokud si ovšem nechcete sestavit systém sami.)";
@@ -59,6 +60,7 @@ Aptitude::Sections
     php 	"Programovací jazyk PHP a rozšiřující knihovny\n Balíky ze sekce „php“ poskytují programovací jazyk PHP a mnoho rozšiřujících knihoven z dalších zdrojů. Pokud nejste php programátor, nemusíte zde nic vybírat; pokud budou nějaké balíky potřeba, balíkovací systém si díky závislostem nainstaluje vše potřebné.";
     python	"Programovací jazyk Python a rozšiřující knihovny\n Balíky ze sekce „python“ poskytují programovací jazyk Python a mnoho rozšiřujících knihoven z dalších zdrojů. Pokud nejste pythonový programátor, nemusíte zde nic vybírat; pokud budou nějaké balíky potřeba, balíkovací systém si díky závislostem nainstaluje vše potřebné.";
     ruby	"Programovací jazyk Ruby a rozšiřující knihovny\n Balíky ze sekce „ruby“ poskytují programovací jazyk Ruby a mnoho rozšiřujících knihoven z dalších zdrojů. Pokud nejste ruby programátor, nemusíte zde nic vybírat; pokud budou nějaké balíky potřeba, balíkovací systém si díky závislostem nainstaluje vše potřebné.";
+    rust	"Programovací jazyk Rust, knihovny a vývojářské nástroje\n Balíky ze sekce „rust“ poskytují programovací jazyk Rust, systém pro správu balíků Cargo, nástroje pro vývoj v jazyce Rust a zdrojové kódy Rust knihoven používaných pro sestavení Rust aplikací.";
     science	"Software pro vědeckou práci\n Balíky ze sekce „science“ zahrnují nástroje pro astronomii, biologii, chemii a software pro spřízněné obory.";
     shells	"Shelly a alternativní konzolová prostředí\n Balíky ze sekce „shells“ obsahují programy s řádkovým rozhraním.";
     sound	"Nástroje pro přehrávání a nahrávání zvuků\n Balíky ze sekce „sound“ zahrnují přehrávače, rekordéry a enkodéry mnoha formátů, mixážní pulty a ovladače hlasitosti, MIDI sekvencery, programy pro zápis not, ovladače zvukových zařízení a software pro zpracování zvuku.";
