@@ -1,6 +1,7 @@
 // apt_options.cc
 //
 //   Copyright (C) 2000, 2007-2008 Daniel Burrows
+//   Copyright (C) 2015-2016 Manuel A. Fernandez Montecelo
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -14,8 +15,8 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program; see the file COPYING.  If not, write to
-//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//   Boston, MA 02111-1307, USA.
+//   the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//   Boston, MA 02110-1301, USA.
 
 #include "apt_options.h"
 #include "apt_config_treeitems.h"
@@ -290,13 +291,18 @@ option_item misc_options[]={
 		 "cache any package files that can no longer be "
 		 "downloaded from any archive in sources.list."),
 	      PACKAGE "::AutoClean-After-Update", false),
+  option_item(N_("Remove all package files after successful operations (e.g. install)"),
+	      N_("If this option is enabled, then after packages are "
+		 "installed successfully (or similar operations) all "
+		 "the package files in the download area will be deleted."),
+	      PACKAGE "::Clean-After-Install", false),
   option_item(N_("URL to use to download changelogs"),
 	      N_("This option controls the server used to "
 		 "download changelogs.  You "
 		 "should only need to change this if the changelogs move "
 		 "to a different URL."),
 	      "APT::Changelogs::Server",
-	      "http://packages.debian.org/changelogs"),
+	      "http://metadata.ftp-master.debian.org/changelogs"),
   option_item(N_("Display a preview of what will be done before doing it"),
 	      N_("If this option is enabled, then when you ask "
 		 "aptitude to perform an install run, it will "
@@ -343,6 +349,13 @@ option_item misc_options[]={
 		 "receive the log on standard input."),
 	      PACKAGE "::Log",
 	      "/var/log/aptitude"),
+  option_item(N_("Use localized messages and dates in the log"),
+	      N_("If this option is enabled, aptitude will use the "
+		 "user's locale for messages and dates in the log "
+		 "file; otherwise the \"classic\" locale is used "
+		 "for this purpose."),
+	      PACKAGE "::Localize-Log",
+	      false),
   option_item()
 };
 
@@ -576,6 +589,19 @@ option_item dependency_options[]={
 	    tree->connect_key("DescriptionDown", &cw::config::global_bindings,
 			      sigc::mem_fun(*desc_area.unsafe_get_ref(),
 					    &cw::text_layout::line_down));
+
+	    // for #453853.  has to be done at the same time for all elements,
+	    // or perhaps there should be a group of all the elements in the
+	    // bottom half of the screen
+	    tree->connect_key("ShowHideDescription", &cw::config::global_bindings,
+				   sigc::mem_fun(*desc_area.unsafe_get_ref(),
+						 &cw::widget::toggle_visible));
+	    tree->connect_key("ShowHideDescription", &cw::config::global_bindings,
+				   sigc::mem_fun(*desc_area_scrollbar.unsafe_get_ref(),
+						 &cw::widget::toggle_visible));
+	    tree->connect_key("ShowHideDescription", &cw::config::global_bindings,
+				   sigc::mem_fun(*middle_label.unsafe_get_ref(),
+						 &cw::widget::toggle_visible));
 	  }
 
 	public:
