@@ -1,6 +1,7 @@
 // cmdline_update.cc
 //
 //   Copyright (C) 2004-2008, 2010 Daniel Burrows
+//   Copyright (C) 2015-2016 Manuel A. Fernandez Montecelo
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -14,10 +15,12 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program; see the file COPYING.  If not, write to
-//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//   Boston, MA 02111-1307, USA.
+//   the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//   Boston, MA 02110-1301, USA.
 
 // Local includes:
+#include "cmdline_update.h"
+
 #include "cmdline_util.h"
 
 #include "terminal.h"
@@ -47,8 +50,6 @@ int cmdline_update(int argc, char *argv[], int verbose)
 {
   std::shared_ptr<terminal_io> term = create_terminal();
 
-  _error->DumpErrors();
-
   if(argc!=1)
     {
       fprintf(stderr, _("E: The update command takes no arguments\n"));
@@ -66,10 +67,7 @@ int cmdline_update(int argc, char *argv[], int verbose)
     (cmdline_do_download(&m, verbose, term, term, term, term)
      == download_manager::success ? 0 : -1);
 
-  if(_error->PendingError())
-    rval = -1;
-
-  _error->DumpErrors();
+  aptitude::cmdline::on_apt_errors_print_and_die();
 
   return rval;
 }
