@@ -1,6 +1,7 @@
 // cmdline_user_tag.cc
 //
 //   Copyright (C) 2008-2010 Daniel Burrows
+//   Copyright (C) 2015-2016 Manuel A. Fernandez Montecelo
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -14,8 +15,8 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program; see the file COPYING.  If not, write to
-//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//   Boston, MA 02111-1307, USA.
+//   the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//   Boston, MA 02110-1301, USA.
 
 
 // Local includes:
@@ -53,32 +54,47 @@ namespace aptitude
     {
       enum user_tag_action { action_add, action_remove };
 
-      void do_user_tag(user_tag_action act,
+      void print_result(user_tag_action act,
+			const std::string& tag,
+			const pkgCache::PkgIterator& pkg,
+			int verbose,
+			bool operation_result)
+      {
+	const char* action_str = (act == action_add) ? _("add") : _("remove");
+	if (operation_result && verbose>0)
+	  {
+	    fprintf(stderr, _("Applied user-tag operation '%s' '%s' to: %s\n"),
+		    action_str, tag.c_str(), pkg.FullName(true).c_str());
+	  }
+	else if (!operation_result)
+	  {
+	    fprintf(stderr, _("Failed to apply user-tag operation '%s' '%s' to: %s\n"),
+		    action_str, tag.c_str(), pkg.FullName(true).c_str());
+	  }
+      }
+
+      bool do_user_tag(user_tag_action act,
 		       const std::string &tag,
 		       const pkgCache::PkgIterator &pkg,
 		       int verbose)
       {
+	bool op_result = false;
 	switch(act)
 	  {
 	  case action_add:
-	    if(verbose > 0)
-				// Sometimes also "user-tag" is used!
-	      printf(_("Adding user tag \"%s\" to the package \"%s\".\n"),
-		     tag.c_str(), pkg.Name());
-
-	    (*apt_cache_file)->attach_user_tag(pkg, tag, NULL);
+	    op_result = (*apt_cache_file)->attach_user_tag(pkg, tag, NULL);
 	    break;
 	  case action_remove:
-	    if(verbose > 0)
-	      printf(_("Removing user tag \"%s\" from the package \"%s\".\n"),
-		     tag.c_str(), pkg.Name());
-
-	    (*apt_cache_file)->detach_user_tag(pkg, tag, NULL);
+	    op_result = (*apt_cache_file)->detach_user_tag(pkg, tag, NULL);
 	    break;
 	  default:
-	    fprintf(stderr, "Internal error: bad user tag action %d.", act);
+	    fprintf(stderr, "Internal error: bad user tag action %d", act);
+	    return false;
 	    break;
 	  }
+
+	print_result(act, tag, pkg, verbose, op_result);
+	return op_result;
       }
     }
 
@@ -87,11 +103,14 @@ namespace aptitude
       const std::shared_ptr<terminal_io> term = create_terminal();
 
       user_tag_action action = (user_tag_action)-1;
-
-      if(strcmp(argv[0], "add-user-tag") == 0)
-	action = action_add;
-      else if(strcmp(argv[0], "remove-user-tag") == 0)
-	action = action_remove;
+      if (strcmp(argv[0], "add-user-tag") == 0)
+	{
+	  action = action_add;
+	}
+      else if (strcmp(argv[0], "remove-user-tag") == 0)
+	{
+	  action = action_remove;
+	}
       else
 	{
 	  fprintf(stderr, "Internal error: cmdline_user_tag encountered an unknown command name \"%s\"\n",
@@ -99,29 +118,27 @@ namespace aptitude
 	  return -1;
 	}
 
-      if(argc < 3)
+      if (argc < 3)
 	{
 	  fprintf(stderr,
-		  _("%s: too few arguments; expected at least a tag name and a package.\n"),
+		  _("%s: too few arguments; expected at least a tag name and a package or pattern\n"),
 		  argv[0]);
 	  return -1;
 	}
 
-      _error->DumpErrors();
+      aptitude::cmdline::on_apt_errors_print_and_die();
 
       OpProgress progress;
+      bool operation_needs_lock = true;
+      apt_init(&progress, true, operation_needs_lock, nullptr);
 
-      apt_init(&progress, true);
-      if(_error->PendingError())
-	{
-	  _error->DumpErrors();
-	  return -1;
-	}
+      aptitude::cmdline::on_apt_errors_print_and_die();
 
-      std::string tag(argv[1]);
+      std::string tag = argv[1];
+      int argc_start = 2;
 
       bool all_ok = true;
-      for(int i = 2; i < argc; ++i)
+      for (int i = argc_start; i < argc; ++i)
 	{
 	  if(!aptitude::matching::is_pattern(argv[i]))
 	    {
@@ -134,7 +151,13 @@ namespace aptitude
 		  all_ok = false;
 		}
 	      else
-		do_user_tag(action, tag, pkg, verbose);
+		{
+		  bool result = do_user_tag(action, tag, pkg, verbose);
+		  if (!result)
+		    {
+		      all_ok = false;
+		    }
+		}
 	    }
 	  else
 	    {
@@ -159,19 +182,48 @@ namespace aptitude
 
 		  for(std::vector<std::pair<pkgCache::PkgIterator, ref_ptr<structural_match> > >::const_iterator
 			it = matches.begin(); it != matches.end(); ++it)
-		    do_user_tag(action, tag, it->first, verbose);
+		    {
+		      const pkgCache::PkgIterator& pkg = it->first;
+		      bool result = do_user_tag(action, tag, pkg, verbose);
+		      if (!result)
+			{
+			  all_ok = false;
+			}
+		    }
 		}
 	    }
 	}
 
-      std::shared_ptr<OpProgress> text_progress = make_text_progress(false, term, term, term);
-      if(!(*apt_cache_file)->save_selection_list(*text_progress))
-	return 1;
+      // check for root/permissions -- needs to lock before
+      // (*apt_cache_file)->save_selection_list() below, see #725272
+      {
+	bool could_lock = apt_cache_file->GainLock();
 
-      if(!all_ok)
-	return 2;
+	if (!could_lock || _error->PendingError())
+	  {
+	    _error->DumpErrors();
+	    return -1;
+	  }
+      }
 
-      return 0;
+      int exit_status = 0;
+
+      if (!(*apt_cache_file)->save_selection_list(&progress))
+	{
+	  exit_status = 1;
+	}
+
+      if (!all_ok)
+	{
+	  exit_status = 2;
+	}
+
+      if (!_error->empty(GlobalError::MsgType::NOTICE))
+	{
+	  _error->DumpErrors(GlobalError::MsgType::NOTICE);
+	}
+
+      return exit_status;
     }
   }
 }
