@@ -2,6 +2,7 @@
 
 
 // Copyright (C) 2010 Daniel Burrows
+// Copyright (C) 2015-2016 Manuel A. Fernandez Montecelo
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -15,8 +16,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 
 
@@ -24,6 +25,8 @@
 
 #include "terminal.h"
 
+#include "generic/util/util.h"
+
 #include <aptitude.h>
 
 // System includes:
@@ -115,9 +118,30 @@ namespace aptitude
         if (ioctl(1, TIOCGWINSZ, &ws) != -1 && ws.ws_col >= 5)
           return ws.ws_col;
         else
-          // \todo Should we distinguish between "can't read a
-          // terminal size" and "read a tiny terminal size"?
-          return 80;
+	  {
+	    // special case for dumb terms when not piping/redirecting
+	    if (aptitude::util::is_dumb_terminal() && output_is_a_terminal())
+	      {
+		const char* env_COLUMNS = getenv("COLUMNS");
+		if ( ! strempty(env_COLUMNS))
+		  {
+		    return std::atoi(env_COLUMNS);
+		  }
+	      }
+
+	    // \todo Should we distinguish between "can't read a
+	    // terminal size" and "read a tiny terminal size"?
+
+	    // See #445206, #775671: limiting arbitrarily to "return 80;" as
+	    // before is not very good, some lines got truncated in perfectly
+	    // normal situations.
+	    //
+	    // Using the native size of int (32 or 64-bit in modern machines) is
+	    // probably unneded and maybe creates some performance problems if
+	    // the application misbehaves, so limit to 64K (16-bit limit) for
+	    // the time being.
+	    return UINT16_MAX;
+	  }
       }
 
       int terminal_impl::wcwidth(wchar_t ch)
