@@ -1,6 +1,7 @@
 // infer_reason.cc
 //
 // Copyright 2004 Daniel Burrows
+// Copyright 2015-2016 Manuel A. Fernandez Montecelo
 
 #include "infer_reason.h"
 
@@ -140,6 +141,14 @@ void infer_reason(pkgCache::PkgIterator pkg, set<reason> &reasons)
 	     !((*apt_cache_file)[or_end]&pkgDepCache::DepGInstall))
 	    reasons.insert(reason(d.TargetPkg(), d));
 	}
+
+      // depends on broken packages -- see #342835
+      for (pkgCache::DepIterator d = pkg.CurrentVer().DependsList(); !d.end(); ++d)
+	{
+	  auto state = (*apt_cache_file)[d.TargetPkg()];
+	  if (state.NowBroken() || state.NowPolicyBroken() || state.InstBroken() || state.InstPolicyBroken())
+	    reasons.insert(reason(d.TargetPkg(), d));
+	}
     }
   else if(actionstate==pkg_unused_remove)
     {
@@ -147,14 +156,37 @@ void infer_reason(pkgCache::PkgIterator pkg, set<reason> &reasons)
       //
       // FIXME: should I walk backwards up the dependency chain until
       //       finding something manually installed?
-      for(pkgCache::DepIterator d=pkg.RevDependsList(); !d.end(); ++d)
-	if(d.ParentVer()==d.ParentPkg().CurrentVer() &&
-	   ((*apt_cache_file)[d.ParentPkg()].Delete() ||
-	    (*apt_cache_file)[d.ParentPkg()].InstVerIter(*apt_cache_file)!=d.ParentVer()) &&
-	   (d->Type==pkgCache::Dep::Depends ||
-	    (aptcfg->FindB("APT::Install-Recommends", true) &&
-	     d->Type==pkgCache::Dep::Recommends)))
-	  reasons.insert(reason(d.ParentPkg(), d));
+
+
+      // include the package itself as well as virtual packages provided by this
+      // package
+      std::vector<pkgCache::PkgIterator> all_pkgs;
+      all_pkgs.push_back(pkg);
+      for (pkgCache::PrvIterator prv = candver.ProvidesList(); !prv.end(); ++prv)
+	{
+	  pkgCache::PkgIterator prv_pkg = prv.ParentPkg();
+	  all_pkgs.push_back(prv_pkg);
+	}
+
+      for (const pkgCache::PkgIterator& pkg_considered : all_pkgs)
+	{
+	  for (pkgCache::DepIterator d = pkg_considered.RevDependsList(); !d.end(); ++d)
+	    {
+	      pkgDepCache::StateCache parent_state = (*apt_cache_file)[d.ParentPkg()];
+	      const pkgCache::VerIterator& parent_candver = parent_state.CandidateVerIter(*apt_cache_file);
+
+	      if (d.ParentVer() == d.ParentPkg().CurrentVer() &&
+		  (parent_state.Delete() ||
+		   (parent_state.InstVerIter(*apt_cache_file) != d.ParentVer()) ||
+		   (!parent_candver.end() && !d.IsSatisfied(parent_candver)) ) &&
+		  (d->Type==pkgCache::Dep::Depends ||
+		   d->Type==pkgCache::Dep::Recommends ||
+		   d->Type==pkgCache::Dep::Suggests))
+		{
+		  reasons.insert(reason(d.ParentPkg(), d));
+		}
+	    }
+	}
     }
   else if(actionstate==pkg_auto_hold)
     {
