@@ -37,7 +37,9 @@
 #include <sigc++/functors/mem_fun.h>
 
 #include <apt-pkg/error.h>
+#include <apt-pkg/fileutl.h>
 #include <apt-pkg/pkgrecords.h>
+#include <apt-pkg/progress.h>
 #include <apt-pkg/tagfile.h>
 
 #include <cwidget/generic/util/eassert.h>
