@@ -1,12 +1,30 @@
 /** \file throttle.cc */   // -*-c++-*-
 
+// Copyright (C) 2010 Daniel Burrows
+// Copyright (C) 2015-2018 Manuel A. Fernandez Montecelo
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License as
+// published by the Free Software Foundation; either version 2 of the
+// License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+// General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; see the file COPYING.  If not, write to
+// the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+// Boston, MA 02110-1301, USA.
+
 #include "throttle.h"
 
 // Local includes:
 #include <loggers.h>
 
 // System includes:
-#include <boost/optional.hpp>
+#include <optional>
 
 #include <generic/util/util.h>
 
@@ -14,7 +32,6 @@
 #include <sys/time.h>
 
 using aptitude::Loggers;
-using boost::optional;
 using logging::LoggerPtr;
 
 namespace aptitude
@@ -25,7 +42,7 @@ namespace aptitude
     {
       class throttle_impl : public throttle
       {
-        boost::optional<struct timeval> last_update;
+        std::optional<struct timeval> last_update;
 
         logging::LoggerPtr logger;
 
