@@ -15,8 +15,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; see the file COPYING.  If not, write to
-//  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//  Boston, MA 02111-1307, USA.
+//  the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//  Boston, MA 02110-1301, USA.
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -1742,7 +1742,8 @@ namespace gui
     {
       {
 	cwidget::util::ref_ptr<guiOpProgress> p(guiOpProgress::create());
-	apt_init(p.unsafe_get_ref(), true, NULL);
+	bool operation_needs_lock = true;
+	apt_init(p.unsafe_get_ref(), true, operation_needs_lock, NULL);
       }
 
       if(getuid() == 0 && aptcfg->FindB(PACKAGE "::Update-On-Startup", true))
