@@ -15,8 +15,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 #include "init.h"
 
@@ -102,7 +102,8 @@ namespace gui
       // \todo Display progress somehow (maybe using the notification
       // framework?)
       OpProgress p;
-      apt_init(&p, true, NULL);
+      bool operation_needs_lock = true;
+      apt_init(&p, true, operation_needs_lock, NULL);
 
       // \todo Support update-on-startup once updating is plumbed
       // through.
