@@ -1154,7 +1154,7 @@ int main(int argc, char *argv[])
 	{
 	  // Connect up the "please consume errors" routine for the
 	  // command-line.
-	  consume_errors.connect(sigc::mem_fun(_error, (void (GlobalError::*)()) &GlobalError::DumpErrors));
+	  consume_errors.connect(sigc::mem_fun(_GetErrorObj(), (void (GlobalError::*)()) &GlobalError::DumpErrors));
 
 	  if(update_only || install_only || autoclean_only || clean_only)
 	    {
