@@ -1,6 +1,7 @@
 // view_changelog.cc
 //
 //   Copyright (C) 2004-2005, 2007-2010 Daniel Burrows
+//   Copyright (C) 2015-2016 Manuel A. Fernandez Montecelo
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -14,8 +15,8 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program; see the file COPYING.  If not, write to
-//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//   Boston, MA 02111-1307, USA.
+//   the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//   Boston, MA 02110-1301, USA.
 
 #include <cwidget/config/colors.h>
 #include <cwidget/config/keybindings.h>
@@ -41,6 +42,7 @@
 #include <generic/apt/download_queue.h>
 
 #include <generic/util/util.h>
+#include <generic/util/temp.h>
 
 #include <sigc++/adaptors/bind.h>
 #include <sigc++/functors/mem_fun.h>
@@ -159,6 +161,8 @@ cw::fragment *render_changelog(const cw::util::ref_ptr<aptitude::apt::changelog>
 
 class pkg_changelog_screen : public cw::file_pager, public menu_redirect
 {
+  std::string changelog_filename;
+
   bool last_search_forwards;
 
   void do_search()
@@ -202,10 +206,10 @@ class pkg_changelog_screen : public cw::file_pager, public menu_redirect
   }
 
 protected:
-  pkg_changelog_screen(const temp::name &filename,
+  pkg_changelog_screen(const std::string& filename,
 		       int x = 0, int y = 0,
 		       int width = 0, int height = 0):
-    cw::file_pager(filename.get_name()), last_search_forwards(true)
+    cw::file_pager(filename), changelog_filename(filename), last_search_forwards(true)
   {
     connect_key("Search", &cw::config::global_bindings,
 		sigc::mem_fun(*this, &pkg_changelog_screen::do_search));
@@ -219,7 +223,7 @@ protected:
 
 public:
   static cw::util::ref_ptr<pkg_changelog_screen>
-  create(const temp::name &filename,
+  create(const std::string& filename,
 	 int x = 0, int y = 0, int width = 0, int height = 0)
   {
     cw::util::ref_ptr<pkg_changelog_screen>
@@ -264,7 +268,7 @@ public:
 typedef cw::util::ref_ptr<pkg_changelog_screen> pkg_changelog_screen_ref;
 
 
-static void do_view_changelog(temp::name n,
+static void do_view_changelog(const string& filename,
 			      string pkgname,
 			      string curverstr)
 {
@@ -273,7 +277,7 @@ static void do_view_changelog(temp::name n,
   string tablabel = ssprintf(_("%s changes"), pkgname.c_str());
   string desclabel = _("View the list of changes made to this Debian package.");
 
-  cw::util::ref_ptr<aptitude::apt::changelog> changelog(aptitude::apt::parse_changelog(n));
+  cw::util::ref_ptr<aptitude::apt::changelog> changelog(aptitude::apt::parse_changelog(filename));
   cw::fragment *f = changelog.valid() ? render_changelog(changelog, curverstr) : NULL;
 
   cw::table_ref           t = cw::table::create();
@@ -296,7 +300,7 @@ static void do_view_changelog(temp::name n,
     }
   else
     {
-      pkg_changelog_screen_ref cs = pkg_changelog_screen::create(n);
+      pkg_changelog_screen_ref cs = pkg_changelog_screen::create(filename);
       cw::scrollbar_ref          s = cw::scrollbar::create(cw::scrollbar::VERTICAL);
 
       cs->line_changed.connect(sigc::mem_fun(s.unsafe_get_ref(), &cw::scrollbar::set_slider));
@@ -349,7 +353,7 @@ public:
       download_progress->destroy();
   }
 
-  void success(const temp::name &filename)
+  void success(const std::string& filename)
   {
     if(download_progress.valid())
       {
@@ -360,7 +364,7 @@ public:
     do_view_changelog(filename, pkgname, curverstr);
   }
 
-  void failure(const std::string &msg)
+  void failure(const std::string& msg)
   {
     if(download_progress.valid())
       {
@@ -372,7 +376,7 @@ public:
                           pkgname.c_str(), msg.c_str()));
   }
 
-  void partial_download(const temp::name &name,
+  void partial_download(const std::string& filename,
 			unsigned long long currentSize,
 			unsigned long long totalSize)
   {
@@ -385,11 +389,8 @@ public:
 
 void view_changelog(pkgCache::VerIterator ver)
 {
-  bool in_debian=false;
-
   string pkgname = ver.ParentPkg().Name();
 
-
   pkgCache::VerIterator curver = ver.ParentPkg().CurrentVer();
   std::string current_source_ver;
   if(!curver.end())
@@ -403,17 +404,10 @@ void view_changelog(pkgCache::VerIterator ver)
 	: current_source_rec.SourceVer();
     }
 
-  // TODO: add a configurable association between origins and changelog URLs.
-  for(pkgCache::VerFileIterator vf=ver.FileList();
-      !vf.end() && !in_debian; ++vf)
-    if(!vf.File().end() && vf.File().Origin()!=NULL &&
-       strcmp(vf.File().Origin(), "Debian")==0)
-      in_debian=true;
-
-  if(!in_debian)
+  // check if we know the origin
+  if ( ! aptitude::apt::check_valid_origin(ver) )
     {
-      show_message(_("You can only view changelogs of official Debian packages."),
-		   NULL, cw::get_style("Error"));
+      check_apt_errors();
       return;
     }
 
